# ![api::lgtm](/assets/apilgtm.png)
[![CI](https://github.com/tagdots/apilgtm/actions/workflows/ci.yaml/badge.svg?logo=github&labelColor=222222)](https://github.com/tagdots/apilgtm/actions/workflows/ci.yaml)
[![CodeQL](https://github.com/tagdots/apilgtm/actions/workflows/reusable-codeql.yaml/badge.svg?logo=github&labelColor=222222)](https://github.com/tagdots/apilgtm/actions/workflows/reusable-codeql.yaml)
[![coverage](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/tagdots/apilgtm/refs/heads/badges/badges/coverage.json)](https://github.com/tagdots/apilgtm/actions/workflows/cron-tasks.yaml)

<br>

### 🚀 Python client library to make API LGTM

<br>

## 💪 Install
```
$ pip install -U apilgtm
```

<br>

## 📚 Documentation
[Usage](https://github.com/tagdots/apilgtm/blob/main/docs/README.md)

<br>

## 😕  Troubleshooting

Open an [issue][issues]

<br>

## 🙏 Contributing

For pull requests to be accepted on this project, you should follow [PEP8][pep8] when creating/updating Python codes.

See [Contributing][contributing]

<br>

## 🙌 Appreciation
We hope you find this project helpful, please ⭐ star it.  **Thank you**.

<br>

## ✍️ References

[How to fork a repo](https://docs.github.com/en/pull-requests/collaborating-with-pull-requests/working-with-forks/fork-a-repo)

<br>

[contributing]: https://github.com/tagdots/apilgtm/blob/main/CONTRIBUTING.md
[issues]: https://github.com/tagdots/apilgtm/issues
[pep8]: https://google.github.io/styleguide/pyguide.html
